@@ -67,13 +67,13 @@ class Canvas : public QGraphicsView
 		void getY(double& value);
 
 	protected:
-		void resizeEvent(QResizeEvent* event);
+		void resizeEvent(QResizeEvent* event) Q_DECL_OVERRIDE;
 
 	private:
 		void initValues();
 		QColor rgbDoublesToColor(double r, double g, double b);
 		void drawLine(double x1, double y1, double x2, double y2);
-		void wheelEvent(QWheelEvent *event);
+		void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
 		void scaleView(double scaleFactor);
 
 		QGraphicsScene            *_scene;
